Steamship
=========

Steamship is the fastest way to add Language AI to your software.

Think of us as a package manager for AI.
Each `Steamship package <https://www.steamship.com/packages>`_ runs in the cloud on a managed stack.
The best way to start is to try one out.

First, install our CLI with the following terminal command (you'll need `NPM`_):

.. code-block:: bash

   npm install -g @steamship/cli

Next, select a Steamship :ref:`package<Packages>` to try with:

.. code-block:: bash

   ship try

We'll help you pick a Jupyter Notebook demo you can run on your own machine.

..

Next Steps
==========

.. grid::  1 1 2 3

   .. grid-item-card:: **Using Packages**
      :link: packages/using.html

      Use full-stack language AI packages in your own code.

   .. grid-item-card:: **Developing Packages**
      :link: packages/developing/index.html

      Build and deploy packages with our low-code framework.

   .. grid-item-card:: **Package Cookbook**
      :link: packages/cookbook/index.html

      Package examples for common scenarios.


Contents
========

.. toctree::
   :maxdepth: 4

   Configuration <configuration/index>
   Packages <packages/index>
   Plugins <plugins/index>
   Workspaces <workspaces/index>
   Developer Reference <developing/index>
   Python Client Reference <api/modules>
   License <license>
   Authors <authors>


.. _NPM: http://npmjs.com/
